pub enum AtomicRMWBinOp {
Show 15 variants
Xchg,
Add,
Sub,
And,
Nand,
Or,
Xor,
Max,
Min,
UMax,
UMin,
FAdd,
FSub,
FMax,
FMin,
}Variants
Xchg
Stores to memory and returns the prior value.
Add
Adds to the value in memory and returns the prior value.
Sub
Subtract a value off the value in memory and returns the prior value.
And
Bitwise and into memory and returns the prior value.
Nand
Bitwise nands into memory and returns the prior value.
Or
Bitwise ors into memory and returns the prior value.
Xor
Bitwise xors into memory and returns the prior value.
Max
Sets memory to the signed-greater of the value provided and the value in memory. Returns the value that was in memory.
Min
Sets memory to the signed-lesser of the value provided and the value in memory. Returns the value that was in memory.
UMax
Sets memory to the unsigned-greater of the value provided and the value in memory. Returns the value that was in memory.
UMin
Sets memory to the unsigned-lesser of the value provided and the value in memory. Returns the value that was in memory.
FAdd
Adds to the float-typed value in memory and returns the prior value.
FSub
Subtract a float-typed value off the value in memory and returns the prior value.
FMax
Sets memory to the greater of the two float-typed values, one provided and one from memory. Returns the value that was in memory.
FMin
Sets memory to the lesser of the two float-typed values, one provided and one from memory. Returns the value that was in memory.